@@ -1,7 +1,7 @@
 (*---------------------------------------------------------------------------
    Copyright (c) 2016 Daniel C. Bünzli. All rights reserved.
    Distributed under the ISC license, see terms at the end of the file.
-   topkg v1.0.2
+   topkg v1.0.3
   ---------------------------------------------------------------------------*)
 
 open Topkg_result
@@ -107,7 +107,7 @@ module Install = struct
       field
     in
     let sortable (field, mv) = (field_to_string field, mv) in
-    let moves = List.(sort compare (rev_map sortable mvs)) in
+    let moves = List.sort compare (List.rev_map sortable mvs) in
     pr_header b h;
     let last = List.fold_left (pr_move b) "" moves in
     pr_field_end b last;
